==> deepin-icon-theme_15.12.71.orig.tar.gz: deepin-icon-theme-15.12.71/CHANGELOG.md <==
<a name="15.12.69"></a>
## 15.12.69 (2019-04-04)


#### Bug Fixes

*   default icon name of sqlite db mimetype ([ad55ea12](ad55ea12))
*   default icon name of flac mimetype ([3395fd5f](3395fd5f))
*   default icon name of ttf mimetype ([c73a59ac](c73a59ac))
*   not install cursor icons ([eb911e37](eb911e37))
*   make fctix tray icon seem larger on hiDPI ([583a687a](583a687a))
*   remove dde.svg ([c80ce849](c80ce849))
*   resolve file conflicts with other packages ([e7566f5f](e7566f5f))
*   let deepin cursor theme inherit deepin ([62d882b4](62d882b4))
*   Adapt lintian ([c7141e12](c7141e12))



### 15.12.68
    
     add deepin-virtualkeyboard icons


###  15.12.67
     add stack folder icons and redesigned deepin-launcher icons
###
     15.12.66
      update some trayicons
###
    15.12.65
     update shutdown icons and fix
### 15.12.64
    fix
### 15.12.62
    update action icons
### 15.12.61
    finished Mimetype ,Places and Devices icons

### 15.12.60
     add a new theme

### 15.12.59 (2018-08-07)


#### Bug Fixes

*   make fctix tray icon seem larger on hiDPI ([583a687a](583a687a))

<a name="15.12.58"></a>
### 15.12.58 (2018-06-22)

#### Bug Fixes

*   remove dde.svg ([c80ce849](c80ce849))

## 15.12.57 (2018-05-14)

	Fix typo
          add iphone and android phone icons

# 15.12.56
          redesigned compressed file icons
          redesigned microsoft office document icons
# 15.12.55
 
# 15.12.54
          fix battery symbolic iconns in status/64

# 15.12.53
	add some deepin app icons
	update someother icons
# 15.12.52

# 15.12.51
	update some icons
	add some deepin app family icons
	add and fix several icons

==> deepin-icon-theme_2020.07.24.orig.tar.gz: deepin-icon-theme-2020.07.24/CHANGELOG.md <==
## 2020.07.24
   add deepin phone master icons
## 2020.06.30
   fix several icons for bloom-classic
   delete actions in bloom-classic
   update dim icons for bloom-classic&bloom-classic-dark
## 2020.06.29
   update several edit icons
   fix minimize trash icon
## 2020.06.10 
   fix bloom-classic sidebar icons when used dark theme
   fix fcitx when dock is in minimum size
## 2020.05.29
   add more cursor themes
## 2020.05.28
   add more battery percentage icons for smooth display
## 2020.05.21
   fix trash icons for faster loading
## 2020.05.09
   merge apps icons
## 2020.04.13
   update tag version
## 15.12.74
   Update device manager icons and several other icons
## 15.12.73
    update 
## 15.12.72
   update
## 15.12.71
   update
## 15.12.70
   update all styles for V20
## 15.12.69 (2019-04-04)


#### Bug Fixes

*   default icon name of sqlite db mimetype ([ad55ea12](ad55ea12))
*   default icon name of flac mimetype ([3395fd5f](3395fd5f))
*   default icon name of ttf mimetype ([c73a59ac](c73a59ac))
*   not install cursor icons ([eb911e37](eb911e37))
*   make fctix tray icon seem larger on hiDPI ([583a687a](583a687a))
*   remove dde.svg ([c80ce849](c80ce849))
*   resolve file conflicts with other packages ([e7566f5f](e7566f5f))
*   let deepin cursor theme inherit deepin ([62d882b4](62d882b4))
*   Adapt lintian ([c7141e12](c7141e12))



### 15.12.68
    
     add deepin-virtualkeyboard icons


###  15.12.67
     add stack folder icons and redesigned deepin-launcher icons
###
     15.12.66
      update some trayicons
###
    15.12.65
     update shutdown icons and fix
### 15.12.64
    fix
### 15.12.62
    update action icons
### 15.12.61
    finished Mimetype ,Places and Devices icons

### 15.12.60
     add a new theme

### 15.12.59 (2018-08-07)


#### Bug Fixes

*   make fctix tray icon seem larger on hiDPI ([583a687a](583a687a))

<a name="15.12.58"></a>
### 15.12.58 (2018-06-22)

#### Bug Fixes

*   remove dde.svg ([c80ce849](c80ce849))

## 15.12.57 (2018-05-14)

	Fix typo
          add iphone and android phone icons

# 15.12.56
          redesigned compressed file icons
          redesigned microsoft office document icons
# 15.12.55
 
# 15.12.54
          fix battery symbolic iconns in status/64

# 15.12.53
	add some deepin app icons
	update someother icons
# 15.12.52

# 15.12.51
	update some icons
	add some deepin app family icons
	add and fix several icons
